#
# spec file for package python-pexpect
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pexpect
Version:        4.3.1
Release:        lp151.2.1
Summary:        Pure Python Expect-like module
License:        ISC
Group:          Development/Libraries/Python
Url:            http://pexpect.readthedocs.org/en/latest/
Source:         https://files.pythonhosted.org/packages/source/p/pexpect/pexpect-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module ptyprocess}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with tests}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-ptyprocess
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Pexpect is a pure Python module for spawning child applications;
controlling them; and responding to expected patterns in their output.

%prep
%setup -n pexpect-%{version}

# Fix wrong-script-interpreter
find examples -type f -name "*.py" -exec sed -i "s|#!/usr/bin/env python||" {} \;
find examples -type f -name "*.cgi" -exec sed -i "s|##!/usr/bin/env python|##!/usr/bin/python|" {} \;

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
export LANG=en_US.UTF-8
%python_expand py.test-%{$python_bun_suffix}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE
%doc doc/
%doc examples/
%{python_sitelib}/pexpect/
%{python_sitelib}/pexpect-%{version}-py*.egg-info

%changelog
* Sat Dec 16 2017 arun@gmx.de
- update to version 4.3.1:
  * When launching bash for pexpect.replwrap, load the system bashrc
    from a couple of different common locations (PR #457), and then
    unset the PROMPT_COMMAND environment variable, which can interfere
    with the prompt we’re expecting (PR #459).
* Fri Nov 10 2017 arun@gmx.de
- update to version 4.3.0:
  * The async= parameter to integrate with asyncio has become async_=
    (PR #431), as async is becoming a Python keyword from Python
    3.6. Pexpect will still recognise async as an alternative
    spelling.
  * Similarly, the module pexpect.async became pexpect._async (PR
    [#450]). This module is not part of the public API.
  * Fix problems with asyncio objects closing file descriptors during
    garbage collection (#347, PR #376).
  * Set the .pid attribute of a PopenSpawn object (PR #417).
  * Fix passing Windows paths to PopenSpawn (PR #446).
  * PopenSpawn on Windows can pass string commands through to Popen
    without splitting them into a list (PR #447).
  * Stop shlex trying to read from stdin when PopenSpawn is passed
    cmd=None (#433, PR #434).
  * Ensure that an error closing a Pexpect spawn object raises a
    Pexpect error, rather than a Ptyprocess error (#383, PR #386).
  * Cleaned up invalid backslash escape sequences in strings (PR #430,
    PR #445).
  * The pattern for a password prompt in pexpect.pxssh changed from
    password to password: (PR #452).
  * Correct docstring for using unicode with spawn (PR #395).
  * Various other improvements to documentation.
* Mon Jul 10 2017 toddrme2178@gmail.com
- Fix wrong-script-interpreter rpmlint error.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Sep 15 2016 toddrme2178@gmail.com
- update to version 4.2.1:
  * Fix to allow running ``env`` in replwrap-ed bash.
  * Raise more informative exception from pxssh if it fails to connect.
  * Change ``passmass`` example to not log passwords entered.
- update to version 4.2.0:
  * Change: When an "env" parameter is specified to the
    :class:`~.spawn` or :class:`~.run` family of calls containing a
    value for "PATH", its value is used to discover the target
    executable from a relative path, rather than the current process's
    environment "PATH".  This mirrors the behavior of
    :func:`subprocess.Popen` in the standard library (:ghissue:`348`).
  * Regression: Re-introduce capability for :meth:`read_nonblocking`
    in class :class:`fdspawn` as previously supported in version 3.3
    (:ghissue:`359`).
- update to version 4.1.0:
  * No upstream changelog
- update to version 4.0.1:
  * Integration with :mod:`asyncio`: passing "async=True" to :meth:`~.spawn.expect`,
    :meth:`~.spawn.expect_exact` or :meth:`~.spawn.expect_list` will make them return a
    coroutine. You can get the result using "yield from", or wrap it in an
    :class:`asyncio.Task`. This allows the event loop to do other things while
    waiting for output that matches a pattern.
  * Experimental support for Windows (with some caveats)—see :ref:`windows`.
  * Enhancement: allow method as callbacks of argument "events" for
    :func:`pexpect.run` (:ghissue:`176`).
  * It is now possible to call :meth:`~.spawn.wait` multiple times, or after a process
    is already determined to be terminated without raising an exception
    (:ghpull:`211`).
  * New :class:`pexpect.spawn` keyword argument, "dimensions=(rows, columns)"
    allows setting terminal screen dimensions before launching a program
    (:ghissue:`122`).
  * Fix regression that prevented executable, but unreadable files from
    being found when not specified by absolute path -- such as
    /usr/bin/sudo (:ghissue:`104`).
  * Fixed regression when executing pexpect with some prior releases of
    the multiprocessing module where stdin has been closed (:ghissue:`86`).
  * Deprecated "pexpect.screen" and "pexpect.ANSI". Please use other packages
    such as `pyte <https://pypi.python.org/pypi/pyte>`__ to emulate a terminal.
  * Removed the independent top-level modules ("pxssh fdpexpect FSM screen ANSI")
    which were installed alongside Pexpect. These were moved into the Pexpect
    package in 3.0, but the old names were left as aliases.
  * Child processes created by Pexpect no longer ignore SIGHUP by default: the
    "ignore_sighup" parameter of :class:`pexpect.spawn` defaults to False. To
    get the old behaviour, pass "ignore_sighup=True".
* Mon Apr 27 2015 tbechtold@suse.com
- update to 3.3:
  * Added a mechanism to wrap REPLs, or shells, in an object which can
    conveniently be used to send commands and wait for the output
    (:mod:`pexpect.replwrap`).
  * Fixed issue where pexpect would attempt to execute a directory because
    it has the 'execute' bit set (:ghissue:`37`).
  * Removed the ``pexpect.psh`` module. This was never documented, and we found
    no evidence that people use it. The new :mod:`pexpect.replwrap` module
    provides a more flexible alternative.
  * Fixed ``TypeError: got <type 'str'> ('\r\n') as pattern`` in
    :meth:`spawnu.readline`
    method (:ghissue:`67`).
  * Fixed issue where EOF was not correctly detected in :meth:`~.interact`,
    causing a repeating loop of output on Linux, and blocking before EOF
    on BSD and Solaris (:ghissue:`49`).
  * Several Solaris (SmartOS) bugfixes, preventing :exc:`IOError` exceptions,
    especially when used with cron(1) (:ghissue:`44`).
  * Added new keyword argument ``echo=True`` for :class:`spawn`.  On SVR4-like
    systems, the method :meth:`~.isatty` will always return *False*: the child
    pty does not appear as a terminal.  Therefore, :meth:`~.setecho`,
    :meth:`~.getwinsize
  * Fix exception handling from :func:`select.select` on Python 2 (:ghpull:`38`)
    This was accidentally broken in the previous release when it was fixed for
    Python 3.
  * Removed a workaround for ``TIOCSWINSZ`` on very old systems, which was
    causing issues on some BSD systems (:ghpull:`40`).
  * Fixed an issue with exception handling in :mod:`~pexpect.pxssh`
    (:ghpull:`43`)
* Fri Apr 11 2014 dmueller@suse.com
- fix license (ISC)
* Thu Apr  3 2014 dmueller@suse.com
- update to 3.1:
  * Fix an issue that prevented importing pexpect on Python 3 when ``sys.stdout``
    was reassigned
  * Improve prompt synchronisation in :mod:`~pexpect.pxssh`
  * Fix pickling exception instances
  * Fix handling exceptions from :func:`select.select` on Python 3
  * A new :ref:`unicode API <unicode>` was introduced.
  * Python 3 is now supported, using a single codebase.
  * Pexpect now requires at least Python 2.6 or 3.2.
  * The modules other than pexpect, such as :mod:`pexpect.fdpexpect` and
  * Ignoring ``SIGHUP`` is now optional
* Thu Oct 24 2013 speilicke@suse.com
- Update to version 2.4:
  + No changelog
* Fri Sep 19 2008 dmueller@suse.de
- fix requires
* Fri Aug  1 2008 bwalle@suse.de
- update to 2.3 (no upstream changelog available)
* Wed Jan 24 2007 timlee@suse.de
- initial submission to autobuild, version 2.1
